searchNodes=[{"type":"module","title":"Utilx","doc":"","ref":"Utilx.html"},{"type":"module","title":"Utilx.BenchUtils","doc":"Utility for quick and simple benchmarking functions in Elixir.","ref":"Utilx.BenchUtils.html"},{"type":"macro","title":"Utilx.BenchUtils.timeit/2","doc":"Benchmarks the execution time of a piece of code. It should be used only in really simple cases. Examples iex&gt; timeit &quot;Sleep for a while&quot;, do: :timer.sleep(1000) Executed Sleep for a while in 1.00 seconds","ref":"Utilx.BenchUtils.html#timeit/2"},{"type":"module","title":"Utilx.EctoUtils","doc":"A utility module for handling Ecto queries, with functions to perform common tasks like applying a range filter, and executing a series of query operations in a pipeline. This module includes Ecto changeset validation functions as well.","ref":"Utilx.EctoUtils.html"},{"type":"function","title":"Utilx.EctoUtils.apply_filters/2","doc":"Applies a series of operations to an Ecto query. Parameters query : The Ecto query to which operations should be applied. opts : A list of operations to apply. Each operation is a tuple where the first element is the operation name and the second element is the value to use for that operation. The following operations are supported: {:where, filters} : Adds a where clause to the query. {:select, fields} : Adds a select clause to the query. {:order_by, criteria} : Adds an order_by clause to the query. {:limit, criteria} : Adds a limit clause to the query. {:preload, preload} : Adds a preload clause to the query. Examples iex&gt; query = from ( u in &quot;users&quot; ) iex&gt; EctoUtils . apply_filters ( query , where : [ age : 18 ] , select : [ :id , :email ] ) # Ecto.Query &lt; from u0 in &quot;users&quot; , where : u0 . age == ^ 18 , select : map ( u0 , [ :id , :email ] ) &gt; iex&gt; query = from ( u in &quot;users&quot; ) iex&gt; filters = [ ...&gt; { :where , [ age : 18 ] } , ...&gt; { :order_by , [ desc : :age ] } , ...&gt; { :select , [ :id , :email ] } , ...&gt; { :limit , 10 } , ...&gt; { :preload , :posts } ...&gt; ] iex&gt; EctoUtils . apply_filters ( query , filters ) # Ecto.Query &lt; from u0 in &quot;users&quot; , where : u0 . age == ^ 18 , order_by : [ desc : u0 . age ] , limit : ^ 10 , select : map ( u0 , [ :id , :email ] ) , preload : [ :posts ] &gt;","ref":"Utilx.EctoUtils.html#apply_filters/2"},{"type":"function","title":"Utilx.EctoUtils.in_range/3","doc":"Filters a query to only include rows where the specified column's value is within a provided range. Parameters query : The Ecto query to filter. column : The column on which to apply the range filter. min..max : The range of values to filter on. Examples iex&gt; query = from ( u in &quot;users&quot; , select : u . age ) iex&gt; EctoUtils . in_range ( query , :age , 18 .. 30 ) # Ecto.Query &lt; from u0 in &quot;users&quot; , where : u0 . age &gt; = ^ 18 and u0 . age &lt;= ^ 30 , select : u0 . age &gt;","ref":"Utilx.EctoUtils.html#in_range/3"},{"type":"function","title":"Utilx.EctoUtils.validate_url/3","doc":"Validates the structure of a URL field in an Ecto changeset. It does not make it required field. If the field in the changeset is a URL, this function ensures that it has a scheme (defaulting to &quot; https://&quot; if none is present), and then checks the URL's structure against a regular expression. If the URL's structure is invalid, the error_message is attached to the field in the changeset 's errors. Parameters changeset : The Ecto changeset containing the URL to validate. field : The key (atom) for the field in the changeset containing the URL. error_message : The error message to attach to the field in the changeset if the URL is invalid. Examples iex&gt; types = %{ url : :string } iex&gt; params = %{ url : &quot;https://www.example.com/&quot; } iex&gt; Ecto.Changeset . cast ( { %{ } , types } , params , Map . keys ( types ) ) ...&gt; |&gt; EctoUtils . validate_url ( :url , &quot;is not a valid url&quot; ) # Ecto.Changeset &lt; action : nil , changes : %{ url : &quot;https://www.example.com/&quot; } , errors : [ ] , data : %{ } , valid? : true &gt; iex&gt; types = %{ url : :string } iex&gt; params = %{ url : &quot;www.example.com/&quot; } iex&gt; Ecto.Changeset . cast ( { %{ } , types } , params , Map . keys ( types ) ) ...&gt; |&gt; EctoUtils . validate_url ( :url , &quot;is not a valid url&quot; ) # Ecto.Changeset &lt; action : nil , changes : %{ url : &quot;https://www.example.com/&quot; } , errors : [ ] , data : %{ } , valid? : true &gt; iex&gt; types = %{ url : :string } iex&gt; params = %{ url : nil } iex&gt; Ecto.Changeset . cast ( { %{ } , types } , params , Map . keys ( types ) ) ...&gt; |&gt; EctoUtils . validate_url ( :url , &quot;is not a valid url&quot; ) # Ecto.Changeset &lt; action : nil , changes : %{ } , errors : [ ] , data : %{ } , valid? : true &gt; iex&gt; types = %{ url : :string } iex&gt; params = %{ url : &quot;some@invalid_url&quot; } iex&gt; Ecto.Changeset . cast ( { %{ } , types } , params , Map . keys ( types ) ) ...&gt; |&gt; EctoUtils . validate_url ( :url , &quot;is not a valid url&quot; ) # Ecto.Changeset &lt; action : nil , changes : %{ url : &quot;https://some@invalid_url&quot; } , errors : [ url : { &quot;is not a valid url&quot; , [ validation : :format ] } ] , data : %{ } , valid? : false &gt; iex&gt; types = %{ url : :string } iex&gt; params = %{ url : &quot;Just some random text&quot; } iex&gt; Ecto.Changeset . cast ( { %{ } , types } , params , Map . keys ( types ) ) ...&gt; |&gt; EctoUtils . validate_url ( :url , &quot;is not a valid url&quot; ) # Ecto.Changeset &lt; action : nil , changes : %{ url : &quot;https://Just some random text&quot; } , errors : [ url : { &quot;is not a valid url&quot; , [ validation : :format ] } ] , data : %{ } , valid? : false &gt;","ref":"Utilx.EctoUtils.html#validate_url/3"},{"type":"module","title":"Utilx.GitUtils","doc":"This module provides utility functions for interacting with Git.","ref":"Utilx.GitUtils.html"},{"type":"function","title":"Utilx.GitUtils.revision_hash/0","doc":"Retrieves the current Git revision hash.","ref":"Utilx.GitUtils.html#revision_hash/0"},{"type":"module","title":"Utilx.NamingUtils","doc":"This module encapsulates common tasks related to processing personal names in a standardized format. This module treats names as case-insensitive and returns results in a formatted, readable way.","ref":"Utilx.NamingUtils.html"},{"type":"function","title":"Utilx.NamingUtils.capitalize/1","doc":"Capitalizes the first letter of each word in a name. Parameters name : A string representing a full name, or nil . Examples iex&gt; NamingUtils . capitalize ( nil ) &quot;&quot; iex&gt; NamingUtils . capitalize ( &quot;&quot; ) &quot;&quot; iex&gt; NamingUtils . capitalize ( &quot;john doe&quot; ) &quot;John Doe&quot; iex&gt; NamingUtils . capitalize ( &quot;JOHN DOE&quot; ) &quot;John Doe&quot; iex&gt; NamingUtils . capitalize ( &quot;john nommensen duchac&quot; ) &quot;John Nommensen Duchac&quot;","ref":"Utilx.NamingUtils.html#capitalize/1"},{"type":"function","title":"Utilx.NamingUtils.extract_first_last_name/1","doc":"Extracts and capitalizes the first and last names from a given name. Parameters name : A string representing a full name, or nil . Examples iex&gt; NamingUtils . extract_first_last_name ( nil ) &quot;&quot; iex&gt; NamingUtils . extract_first_last_name ( &quot;&quot; ) &quot;&quot; iex&gt; NamingUtils . extract_first_last_name ( &quot;john&quot; ) &quot;John&quot; iex&gt; NamingUtils . extract_first_last_name ( &quot;john doe smith&quot; ) &quot;John Smith&quot;","ref":"Utilx.NamingUtils.html#extract_first_last_name/1"},{"type":"function","title":"Utilx.NamingUtils.extract_initials/1","doc":"Extracts the initials from a given name. This function takes a name (a string of one or more words), and extracts the first letter of the first name and the family name. Parameters name : A string representing a full name, or nil . Examples iex&gt; NamingUtils . extract_initials ( nil ) &quot;&quot; iex&gt; NamingUtils . extract_initials ( &quot;&quot; ) &quot;&quot; iex&gt; NamingUtils . extract_initials ( &quot;John&quot; ) &quot;J&quot; iex&gt; NamingUtils . extract_initials ( &quot;John Doe&quot; ) &quot;JD&quot; iex&gt; NamingUtils . extract_initials ( &quot;John Nommensen Duchac&quot; ) &quot;JD&quot;","ref":"Utilx.NamingUtils.html#extract_initials/1"},{"type":"function","title":"Utilx.NamingUtils.shorten_firstname/1","doc":"Shortens the first name to its initial, while preserving the rest of the name. This function takes a name (a string of one or more words), and reduces the first name to its initial. The rest of the name is preserved. The initial is followed by a period and a space, and then the rest of the name. Parameters name : A string representing a full name, or nil . Examples iex&gt; NamingUtils . shorten_firstname ( nil ) &quot;&quot; iex&gt; NamingUtils . shorten_firstname ( &quot;&quot; ) &quot;&quot; iex&gt; NamingUtils . shorten_firstname ( &quot;John&quot; ) &quot;J.&quot; iex&gt; NamingUtils . shorten_firstname ( &quot;john&quot; ) &quot;J.&quot; iex&gt; NamingUtils . shorten_firstname ( &quot;John Doe&quot; ) &quot;J. Doe&quot; iex&gt; NamingUtils . shorten_firstname ( &quot;john doe&quot; ) &quot;J. Doe&quot; iex&gt; NamingUtils . shorten_firstname ( &quot;john doe jr&quot; ) &quot;J. Doe Jr&quot;","ref":"Utilx.NamingUtils.html#shorten_firstname/1"}]